@@ -170,7 +170,7 @@ class _TrayScrollButton(ToolButton):
 
         self.set_size_request(style.GRID_CELL_SIZE, style.GRID_CELL_SIZE)
 
-        self.icon = Icon(icon_name = icon_name,
+        self.icon = Icon(icon_name=icon_name,
                          icon_size=gtk.ICON_SIZE_SMALL_TOOLBAR)
         # The alignment is a hack to work around gtk.ToolButton code
         # that sets the icon_size when the icon_widget is a gtk.Image
@@ -396,7 +396,7 @@ class TrayButton(ToolButton):
 
 class _IconWidget(gtk.EventBox):
 
-    __gtype_name__ = "SugarTrayIconWidget"
+    __gtype_name__ = 'SugarTrayIconWidget'
 
     def __init__(self, icon_name=None, xo_color=None):
         gtk.EventBox.__init__(self)
@@ -422,7 +422,7 @@ class _IconWidget(gtk.EventBox):
 
 class TrayIcon(gtk.ToolItem):
 
-    __gtype_name__ = "SugarTrayIcon"
+    __gtype_name__ = 'SugarTrayIcon'
 
     def __init__(self, icon_name=None, xo_color=None):
         gtk.ToolItem.__init__(self)
